@@ -1,5 +1,5 @@
 package IO::All;
-$IO::All::VERSION = '0.58';
+$IO::All::VERSION = '0.59';
 use 5.006001;
 use strict;
 use warnings;
@@ -730,7 +730,7 @@ sub utf8 {
     CORE::binmode($self->io_handle, ':encoding(UTF-8)')
       if $self->is_open;
     $self->_utf8(1);
-    $self->encoding('utf8');
+    $self->encoding('UTF-8');
     return $self;
 }
 
